@@ -118,7 +118,7 @@ to the next."
       (:a.tab-button
        :class (when (equal section 'keybindings) "active")
        :href (nyxt-url 'common-settings :section 'keybindings)
-       "Keybindings")
+       "Keyboard shortcuts")
       (:a.tab-button
        :class (when (equal section 'theme-and-style) "active")
        :href (nyxt-url 'common-settings :section 'theme-and-style)
@@ -139,22 +139,23 @@ to the next."
       (case section
         (keybindings
          (:div.section
-          (:h3 "Keybinding mode")
+          (:h3 "Keybindings")
           (:div.row
            (:div.left
             (:nradio
               :name "keyscheme"
               :vertical t
-              :checked (cond
-                         ((find 'nyxt/mode/emacs:emacs-mode (default-modes (current-buffer))) 'emacs)
-                         ((find 'nyxt/mode/vi:vi-normal-mode (default-modes (current-buffer))) 'vi)
-                         ((find 'nyxt/mode/vi:vi-insert-mode (default-modes (current-buffer))) 'vi)
-                         (t 'cua))
+              :checked (cond ((find "nyxt/mode/vi" (default-modes (current-buffer))
+                                    :key #'uiop:symbol-package-name :test #'string-equal)
+                              'vi)
+                             ((find "nyxt/mode/emacs" (default-modes (current-buffer))
+                                    :key #'uiop:symbol-package-name :test #'string-equal)
+                              'emacs)
+                             (t 'cua))
               :buffer buffer
               '(cua "CUA (default)"
                 (nyxt::auto-configure
-                 :form '(define-configuration (web-buffer prompt-buffer
-                                               panel-buffer nyxt/mode/editor:editor-buffer)
+                 :form '(define-configuration (input-buffer)
                          ((default-modes (remove-if (lambda (m)
                                                       (find (symbol-name m)
                                                             '("EMACS-MODE" "VI-NORMAL-MODE" "VI-INSERT-MODE")
@@ -162,17 +163,20 @@ to the next."
                                           %slot-value%))))))
               '(emacs "Emacs"
                 (nyxt::auto-configure
-                 :form '(define-configuration (web-buffer prompt-buffer
-                                               panel-buffer nyxt/mode/editor:editor-buffer)
+                 :form '(define-configuration (input-buffer)
                          ((default-modes (pushnew 'nyxt/mode/emacs:emacs-mode %slot-value%))))))
               '(vi "vi"
-                (nyxt::auto-configure
-                 :form '(define-configuration (web-buffer prompt-buffer
-                                               panel-buffer nyxt/mode/editor:editor-buffer)
-                         ((default-modes (pushnew 'nyxt/mode/vi:vi-normal-mode %slot-value%))))))))
+                (progn
+                  (nyxt::auto-configure
+                   :form '(define-configuration (input-buffer)
+                           ((default-modes (pushnew 'nyxt/mode/vi:vi-normal-mode %slot-value%)))))
+                  (nyxt::auto-configure
+                   :form '(define-configuration (prompt-buffer)
+                           ((default-modes (pushnew 'nyxt/mode/vi:vi-insert-mode %slot-value%)))))))))
            (:div.right
-            (:p "For individual buffers - keyschemes can be toggled with the (toggle-modes) command.")
-            (:p "For a persistent keyscheme each time you start Nyxt - make a selection here.")))))
+            (:p "Set the default keybindings (requires restarting Nyxt).")
+            (:p "Keybindings can also be enabled on a per-buffer basis by
+invoking the " (:nxref :command 'toggle-modes) "command.")))))
         (theme-and-style
          (:div.section
           (:h3 "Browser interface")
@@ -193,7 +197,7 @@ to the next."
                 (nyxt::auto-configure :form '(define-configuration browser
                                               ((theme theme::+dark-theme+)))))))
            (:div.right
-            (:p "Themes for the browser interface, panel buffers, and internal Nyxt pages like manual, bindings, and common settings."))))
+            (:p "Themes for Nyxt's UI."))))
          (:div.section
           (:h3 "Webpage theme")
           (:div.row
@@ -205,21 +209,20 @@ to the next."
                            'auto)
               :vertical t
               :buffer buffer
-              '(auto "Default Web"
+              '(auto "Default"
                 (nyxt::auto-configure
                  :form '(define-configuration (web-buffer)
                          ((default-modes (remove-if (lambda (m)
                                                       (string= (symbol-name m) "DARK-MODE"))
                                           %slot-value%))))))
-              '(dark "Darkened Web"
+              '(dark "Darkened"
                 (nyxt::auto-configure
                  :form '(define-configuration (web-buffer)
                          ((default-modes (pushnew 'nyxt/mode/style:dark-mode %slot-value%))))))))
            (:div.right
-            (:p "Select Default Web to view webpages as they are designed.")
-            (:p "Select Dark Web to have Nyxt darken any webpage you visit."))))
+            (:p "Select Darkened to style webpages with a dark background."))))
          (:div.section
-          (:h3 "Default zoom ratio")
+          (:h3 "Default zoom")
           (:div.row
            (:div.left
             (:nselect
@@ -232,15 +235,13 @@ to the next."
                               (nyxt::auto-configure
                                :class-name 'document-buffer
                                :slot 'zoom-ratio-default
-                               :slot-value ,(/ number 100.0))))))
-           (:div.right
-            (:p "Incremental changes advised.")))))
+                               :slot-value ,(/ number 100.0)))))))))
         (buffer-defaults
          (:div.section
           (:h3 "Homepage")
           (:div.row
            (:div.left
-            (:nbutton :text "Set default new buffer URL"
+            (:nbutton :text "Set default URL"
               '(nyxt::configure-slot 'default-new-buffer-url 'browser
                 :sources (list
                           (make-instance
@@ -254,7 +255,7 @@ to the next."
                 :postprocess (lambda (url-or-history-entry)
                                (render-url (url url-or-history-entry))))))
            (:div.right
-            (:p "Choose your homepage. By default your homepage is set to the internal Nyxt page (nyxt:new)."))))
+            (:p "By default, it is set to Nyxt's home screen."))))
          (:div.section
           (:h3 "Session")
           (:div.row
@@ -273,7 +274,7 @@ to the next."
                  :slot 'restore-session-on-startup-p
                  :slot-value nil))))
            (:div.right
-            (:p "Choose whether to restore buffers from previous sessions."))))
+            (:p "Restore buffers from previous sessions."))))
          (:div.section
           (:h3 "Modes")
           (:div.row
@@ -287,8 +288,11 @@ to the next."
                                `(quote ,modes))
                 :type 'cons)))
            (:div.right
-            (:p "Specify default modes for all new buffers.")
-            (:p "To set modes for individual buffers, use the (toggle-modes) command, or a specific command like (toggle-no-script-mode).")))))
+            (:p "Specify default modes for new buffers.")
+            (:p "Modes can also be set interactively by command "
+                (:nxref :command 'toggle-modes)
+                " ,or by specific mode togglers such as "
+                (:nxref :command 'nyxt/mode/no-script:no-script-mode) ".")))))
         (privacy-and-security
          (:div.section
           (:h3 "Privacy & Security Modes")
@@ -334,7 +338,7 @@ to the next."
                                                       (string= (symbol-name m) "REDUCE-TRACKING-MODE"))
                                           %slot-value%))))))))
            (:div.right
-            (:p "Select commonly used security modes here to add them to your default modes for new buffers."))))
+            (:p "Select security modes to be enabled by default on web buffers."))))
          (:div.section
           (:h3 "Cookie policy")
           (:div.row
@@ -358,23 +362,19 @@ to the next."
                 (nyxt::auto-configure
                  :class-name 'browser
                  :slot 'default-cookie-policy
-                 :slot-value :never))))
-           (:div.right
-            (:p "To accept cookies for current website only, choose \"No third party\".")
-            (:p "To always accept cookies, choose \"Always accept\".")
-            (:p "To never accept cookies, choose \"Never accept\".")))))
+                 :slot-value :never)))))))
         (text-and-code
          (:div.section
           (:h3 "Edit user files")
           (:div.row
            (:div.left
-            (:nbutton :text "Use internal editor"
+            (:nbutton :text "Use Nyxt's editor"
               '(nyxt/mode/editor::edit-user-file))
             (:nbutton :text "Use external editor"
               '(nyxt::edit-user-file-with-external-editor)))
            (:div.right
-            (:p "To use the external editor, you need to set the VISUAL or EDITOR environment variables on your system.")
-            (:p "Otherwise, you can use the basic internal text editor."))))))))))
+            (:p "To use the external editor, please set the " (:code "VISUAL") " or "
+                (:code "EDITOR") "environment variables."))))))))))
 
 (define-command print-bindings ()
   "Display all known bindings for the current buffer."
@@ -467,7 +467,7 @@ The value is saved to clipboard."
         :background-color ,theme:action
         :border "none"
         :border-width "2px"
-        :border-radius "3px"
+        :border-radius "2px"
         :margin-bottom "17px")
       `(.execute-command
         :min-width "180px"
@@ -596,3 +596,28 @@ clipboard."
         (:ul (:raw (history-html-list :limit 50)))
         (:h3 (:b "Recent bookmarks"))
         (:ul (:raw (list-bookmarks :limit 50)))))))
+
+(define-internal-page-command-global list-extensions
+    (&key (endpoint "https://nyxt-browser.com/api/extensions"))
+    (buffer "*Nyxt extensions*" 'nyxt/mode/help:help-mode)
+  "List available extensions for Nyxt.
+The `:download-link' is overloaded as a reference URL for external extensions as
+they are not served on the Nyxt website."
+  (flet ((extension->html (extension)
+           (spinneret:with-html-string
+             (:dl
+              (:dt "Name")
+              (:dd (alex:assoc-value extension :name))
+              (:dt "Description")
+              (:dd (alex:assoc-value extension :description))
+              (:dt "Link")
+              (let ((link (if (alex:assoc-value extension :internal-p)
+                              (format nil "https://nyxt-browser.com~a"
+                                      (alex:assoc-value extension :link))
+                              (alex:assoc-value extension :download-link))))
+                (:dd (:a :href link link)))))))
+    (spinneret:with-html-string
+      (:h1 "Nyxt extensions")
+      (loop for extension in (cl-json:decode-json-from-string (dex:get endpoint))
+            collect (:div (:raw (extension->html extension))
+                          (:hr))))))
