@@ -1066,6 +1066,10 @@ corrupt data file like the history.")
 thus are not visible to the Nyxt-native debugger and fixable on the side of
 Nyxt. See below."))
 
+        (:nsection :title "Bwrap error on initialization (Ubuntu)"
+          (:p "If Nyxt crashes on start due to " (:code "bwrap")
+              ", then disable or configure the " (:code "apparmor") " service."))
+
         (:nsection :title "Playing videos"
           (:p "Nyxt delegates video support to third-party plugins.")
           (:p "When using the WebKitGTK backends, GStreamer and its plugins are
@@ -1119,10 +1123,9 @@ nyxt
                "StumpWM FAQ")
               " for a fix."))
 
-        (:nsection :title "Blank WebKit web-views"
-          (:p "If you are experiencing problems with blank web-views on some sites you
-    can try to disable compositing. To disable compositing from your
-    initialization file, you can do the following: ")
+        (:nsection :title "Blank WebKitGTK views"
+          (:p "When experiencing rendering issues, try to disable compositing as
+below: ")
           (:ncode
             '(setf (uiop:getenv "WEBKIT_DISABLE_COMPOSITING_MODE") "1")))
 
