@@ -17,7 +17,7 @@
       :reader height
       :documentation "The height occupied by the prompt buffer.
 The options are:
-- `:default', which sets it to the value of `prompt-buffer-open-height';
+- `:default', which sets it to a third of the window's height;
 - `:fit-to-prompt', which shrinks the height to fit the input area;
 - an integer, which corresponds to the height in pixels.")
      (resumable-p t
@@ -174,13 +174,13 @@ See `nyxt::attribute-widths'.")
           :background-color ,theme:background
           :color ,theme:on-background
           :opacity 0.9
-          :border "none"
+          :border 2px solid ,theme:secondary
           :outline "none"
           :padding "3px"
           :width "100%"
           :autofocus "true")
         `("#input:focus"
-          :box-shadow inset 0 0 0 3px ,(cl-colors2:print-hex theme:action- :alpha 0.40))
+          :border-color ,(cl-colors2:print-hex theme:action- :alpha 0.40))
         `(".source"
           :margin-left "10px"
           :margin-top "15px")
@@ -191,11 +191,11 @@ See `nyxt::attribute-widths'.")
           :display "flex"
           :justify-content "space-between"
           :align-items "stretch"
-          :border-radius "2px 0 0 0")
+          :border-radius "2px")
         '(".source-name > div"
           :line-height "22px")
         `(".source-name > div > button"
-          :padding "5px 4px 5px 4px"
+          :padding "5px 5px 5px 0px"
           :min-height "100%")
         `("#next-source > svg, #previous-source > svg"
           :margin-bottom "2px"
@@ -214,10 +214,14 @@ See `nyxt::attribute-widths'.")
         `(".suggestion-and-mark-count"
           :font-family ,theme:monospace-font-family)
         `(".source-content"
-          :margin-left "16px"
+          :box-sizing "border-box"
+          :padding-left "16px"
+          :margin-left "2px"
           :width "100%"
           :table-layout "fixed"
           (td
+           :color ,theme:on-background
+           :border-radius "2px"
            :white-space "nowrap"
            :height "20px"
            :padding-left "4px"
@@ -233,6 +237,7 @@ See `nyxt::attribute-widths'.")
            :color ,theme:on-primary
            :font-weight "normal"
            :padding-left "4px"
+           :border-radius "2px"
            :text-align "left")
           ("td::-webkit-scrollbar"
            :display "none"))
@@ -279,8 +284,7 @@ See `prompt' for how to invoke prompts.")
 (defmethod (setf height) (value (prompt-buffer prompt-buffer))
   (setf (ffi-height prompt-buffer)
         (case value
-          (:default
-           (prompt-buffer-open-height (window prompt-buffer)))
+          (:default (round (/ (ffi-height (window prompt-buffer)) 3)))
           (:fit-to-prompt
            (ps-eval :buffer prompt-buffer
              (+ (ps:chain (nyxt/ps:qs document "#prompt-area") offset-height)
