@@ -75,32 +75,27 @@ forms in BUFFER."
 (defun %nselect-options (clauses)
   "Produces a set of options for :nselect based on CLAUSES list."
   (spinneret:with-html-string
-    (loop for (value display title) in (mapcar (alexandria:compose #'uiop:ensure-list #'first) clauses)
+    (loop for (value display title) in (mapcar (alexandria:compose #'uiop:ensure-list
+                                                                   #'first)
+                                               clauses)
           collect (:option
                    :value (nyxt:prini-to-string value)
-                   (when title
-                     (list :title title))
+                   (when title (list :title title))
                    (string-capitalize (or display (nyxt:prini-to-string value)))))))
 
 (deftag :nselect (body attrs &rest keys &key default (id (alexandria:required-argument 'id)) buffer &allow-other-keys)
   "Generate <select> tag from the BODY resembling cond clauses.
 
-BODY can be:
-- Multiple forms, each following/producing one of the formats:
-  - (VALUE . FORMS) -- creates <option value=\"value\">value</option> and runs
-    FORMS when it's selected.
-  - ((VALUE DISPLAY TITLE) . FORMS) -- creates an <option value=\"value\"
-    title=\"title\">display</option> and runs FORMS when it's selected. DISPLAY
-    and TITLE are optional literal strings.
-- A single form, expected to produce a list of forms like above.
+BODY is a list of forms, each given by ((VALUE DISPLAY TITLE) . FORMS).
+It expands to <option value=\"value\" title=\"title\">display</option> and runs
+FORMS when selected. DISPLAY and TITLE are optional literal strings.
 
 In both cases, VALUEs should be literal (and printable) atoms. For instance,
 symbol, number, string, or keyword.
 
 BUFFER is a buffer to bind the actions of this tag to.
 
-DEFAULT is a string or a string-producing form that is used as the default
-option.
+DEFAULT is a form evaluating to a string that is used as the default option.
 
 In case some variable from the outer scope should be captured, injecting a
 closure into the clause would work best.
@@ -115,9 +110,7 @@ Example:
     (with-gensyms (body-var)
       (let ((keys keys))
         (declare (ignorable keys))
-        `(let ((,body-var ,(if (serapeum:single body)
-                               (first body)
-                               `(list ,@body))))
+        `(let ((,body-var ,@body))
            (:select.button
             ,@attrs
             :id ,id
@@ -471,13 +464,10 @@ LISTING is the string to enrich, autogenerated from FORM on demand."
                          (first body)
                          (%ncode-prini (first body) package))))))
 
-;; TODO: Store the location it's defined in as a :title or link for discoverability?
-;; FIXME: Maybe use :nyxt-user as the default package to not quarrel with REPL & config?
 (deftag :ncode (body attrs &rest keys &key
                      (package :nyxt)
                      (inline-p nil inline-provided-p)
-                     (repl-p t) (config-p t) (copy-p t)
-                     file (editor-p file) (external-editor-p file)
+                     (copy-p t) file (editor-p file) (external-editor-p file)
                      &allow-other-keys)
   "Generate the <pre>/<code> listing from the provided Lisp BODY.
 
@@ -488,8 +478,6 @@ syntax highlighting and actions. If not provided, is determined automatically
 based on BODY length.
 
 Most *-P arguments mandate whether to add the buttons for:
-- Editing the BODY in the built-in REPL (REPL-P).
-- Appending the BODY to the auto-config.lisp (CONFIG-P).
 - Copying the source to clipboard (COPY-P).
 - Editing the FILE it comes from (if present), in
   - Nyxt built-in `nyxt/mode/editor:editor-mode' (EDITOR-P).
@@ -505,38 +493,23 @@ Most *-P arguments mandate whether to add the buttons for:
                   :class "code-select"
                   :default "☰"
                   :style (if ,inline-var "font-weight: bold" "font-weight: normal")
-                  ,@(when copy-p
-                      `(`((copy "Copy" "Copy the code to clipboard.")
-                          (funcall (read-from-string "nyxt:ffi-buffer-copy")
-                                   (nyxt:current-buffer) ,,plaintext))))
-                  ,@(when config-p
-                      `(`((config
-                           "Add to auto-config"
-                           (format nil "Append this code to the auto-configuration file (~a)."
-                                   (nfiles:expand nyxt::*auto-config-file*)))
-                          (alexandria:write-string-into-file
-                           ,,plaintext (nfiles:expand nyxt::*auto-config-file*)
-                           :if-exists :append
-                           :if-does-not-exist :create))))
-                  ,@(when repl-p
-                      `(`((repl
-                           "Try in REPL"
-                           "Open this code in Nyxt REPL to experiment with it.")
-                          (nyxt:buffer-load-internal-page-focus
-                           (read-from-string "nyxt/mode/repl:repl")
-                           :form ,,plaintext))))
-                  ,@(when (and file editor-p)
-                      `(`((editor
-                           "Open in built-in editor"
-                           "Open the file this code comes from in Nyxt built-in editor-mode.")
-                          (funcall (read-from-string "nyxt/mode/editor:edit-file")
-                                   ,,file-var))))
-                  ,@(when (and file external-editor-p)
-                      `(`((external-editor
-                           "Open in external editor"
-                           "Open the file this code comes from in external editor.")
-                          (funcall (read-from-string "nyxt/mode/file-manager:edit-file-with-external-editor")
-                                   (uiop:ensure-list ,,file-var))))))))
+                  (list
+                   ,@(when copy-p
+                       `(`((copy "Copy" "Copy the code to clipboard.")
+                           (funcall (read-from-string "nyxt:ffi-buffer-copy")
+                                    (nyxt:current-buffer) ,,plaintext))))
+                   ,@(when (and file editor-p)
+                       `(`((editor
+                            "Open in built-in editor"
+                            "Open the file this code comes from in Nyxt built-in editor-mode.")
+                           (funcall (read-from-string "nyxt/mode/editor:edit-file")
+                                    ,,file-var))))
+                   ,@(when (and file external-editor-p)
+                       `(`((external-editor
+                            "Open in external editor"
+                            "Open the file this code comes from in external editor.")
+                           (funcall (read-from-string "nyxt/mode/file-manager:edit-file-with-external-editor")
+                                    (uiop:ensure-list ,,file-var)))))))))
         (declare (ignorable keys))
         `(let* ((,body-var (list ,@body))
                 (,first (first ,body-var))
@@ -564,7 +537,6 @@ Most *-P arguments mandate whether to add the buttons for:
            (declare (ignorable ,plaintext ,file-var))
            ,(if inline-p
                 `(:span (:code ,@attrs (:raw ,htmlized)) ,select-code)
-                ;; https://spdevuk.com/how-to-create-code-copy-button/
                 `(:div :style "position: relative"
                        (:pre ,@attrs ,select-code
                              (:code (:raw ,htmlized))))))))))
